@@ -1,11 +1,14 @@
 from __future__ import annotations
 
-from enum import IntEnum
-from typing import List
+from typing import List, Tuple
 
 from AoE2ScenarioParser.datasets import effects
+from AoE2ScenarioParser.datasets.effects import EffectId
+from AoE2ScenarioParser.datasets.trigger_lists import ObjectAttribute
+from AoE2ScenarioParser.helper.bytes_conversions import int_to_bytes, bytes_to_int
 from AoE2ScenarioParser.helper.helper import raise_if_not_int_subclass
 from AoE2ScenarioParser.helper.list_functions import listify
+from AoE2ScenarioParser.helper.printers import warn
 from AoE2ScenarioParser.objects.aoe2_object import AoE2Object
 from AoE2ScenarioParser.sections.retrievers.retriever_object_link import RetrieverObjectLink
 from AoE2ScenarioParser.sections.retrievers.support import Support
@@ -18,10 +21,6 @@ class Effect(AoE2Object):
         RetrieverObjectLink("effect_type", "Triggers", "trigger_data[__index__].effect_data[__index__].effect_type"),
         RetrieverObjectLink("ai_script_goal", "Triggers",
                             "trigger_data[__index__].effect_data[__index__].ai_script_goal"),
-        RetrieverObjectLink("armour_attack_quantity", "Triggers",
-                            "trigger_data[__index__].effect_data[__index__].armour_attack_quantity"),
-        RetrieverObjectLink("armour_attack_class", "Triggers",
-                            "trigger_data[__index__].effect_data[__index__].armour_attack_class"),
         RetrieverObjectLink("quantity", "Triggers", "trigger_data[__index__].effect_data[__index__].quantity"),
         RetrieverObjectLink("tribute_list", "Triggers", "trigger_data[__index__].effect_data[__index__].tribute_list"),
         RetrieverObjectLink("diplomacy", "Triggers", "trigger_data[__index__].effect_data[__index__].diplomacy"),
@@ -142,10 +141,18 @@ class Effect(AoE2Object):
                  ):
         raise_if_not_int_subclass([object_list_unit_id, technology, object_list_unit_id_2])
 
+        # Set flags
+        self._armour_attack_flag = _set_armour_attack_flag(effect_type, object_attributes)
+
+        if self._armour_attack_flag and quantity is not None:
+            armour_attack_quantity, armour_attack_class = _quantity_to_aa(quantity)
+            quantity = None
+
         if selected_object_ids is None:
             selected_object_ids = []
 
-        self.effect_type: int = effect_type
+        # Bypass the @property which causes: self._update_armour_attack_flag()
+        self._effect_type: int = effect_type
         self.ai_script_goal: int = ai_script_goal
         self.armour_attack_quantity: int = armour_attack_quantity
         self.armour_attack_class: int = armour_attack_class
@@ -198,6 +205,58 @@ class Effect(AoE2Object):
 
         super().__init__()
 
+    @property
+    def effect_type(self):
+        return self._effect_type
+
+    @effect_type.setter
+    def effect_type(self, value):
+        self._effect_type = value
+        self._update_armour_attack_flag()
+
+    @property
+    def object_attributes(self):
+        return self._object_attributes
+
+    @object_attributes.setter
+    def object_attributes(self, value):
+        self._object_attributes = value
+        self._update_armour_attack_flag()
+
+    @property
+    def armour_attack_quantity(self):
+        return self._armour_attack_quantity
+
+    @armour_attack_quantity.setter
+    def armour_attack_quantity(self, value):
+        if value is not None and value != [] and not self._armour_attack_flag:
+            warn("Setting 'armour_attack_quantity' when the effect doesn't use armour/attack attributes might result in unintended behaviour.")
+        self._armour_attack_quantity = value
+
+    @property
+    def armour_attack_class(self):
+        return self._armour_attack_class
+
+    @armour_attack_class.setter
+    def armour_attack_class(self, value):
+        if value is not None and value != [] and not self._armour_attack_flag:
+            warn("Setting 'armour_attack_class' when the effect doesn't use armour/attack attributes might result in unintended behaviour.")
+        self._armour_attack_class = value
+
+    @property
+    def quantity(self):
+        if self._armour_attack_flag:
+            return _aa_to_quantity(self.armour_attack_quantity, self.armour_attack_class)
+        return self._quantity
+
+    @quantity.setter
+    def quantity(self, value):
+        # Quantity by default, when unused is []
+        if value is not None and value != [] and self._armour_attack_flag:
+            warn("Setting 'effect.quantity' directly in an effect that uses armour/attack attributes might result in unintended behaviour.\n"
+                 "Please use the 'effect.armour_attack_quantity' and 'effect.armour_attack_class' attributes instead.")
+        self._quantity = value
+
     @property
     def selected_object_ids(self) -> List[int]:
         return self._selected_object_ids
@@ -218,9 +277,58 @@ class Effect(AoE2Object):
             attribute_value = getattr(self, attribute)
             if attribute == "effect_type" or attribute_value in [[], [-1], "", " ", -1]:
                 continue
+            # Ignore the quantity value in the print statement when flag is True.
+            if self._armour_attack_flag and attribute == "quantity":
+                continue
+            if attribute in ["armour_attack_quantity", "armour_attack_class"] and not self._armour_attack_flag:
+                continue
             return_string += "\t\t\t\t" + attribute + ": " + str(attribute_value) + "\n"
 
         if return_string == "":
             return "\t\t\t\t<< No Attributes >>\n"
 
         return return_string
+
+    def _update_armour_attack_flag(self):
+        self._armour_attack_flag = _set_armour_attack_flag(self.effect_type, self.object_attributes)
+
+
+def _set_armour_attack_flag(effect_type, object_attributes) -> bool:
+    return (effect_type in [EffectId.CHANGE_OBJECT_ATTACK, EffectId.CHANGE_OBJECT_ARMOR]) or \
+    (effect_type == EffectId.MODIFY_ATTRIBUTE and object_attributes in [
+        ObjectAttribute.ATTACK, ObjectAttribute.ARMOR
+    ])
+
+
+def _quantity_to_aa(quantity: int) -> Tuple[int, int]:
+    """
+    A function to convert the initial quantity value to the quantity and armor/attack values.
+    Unfortunately this problem has to be solved in the object due to how specific this was implemented in DE.
+
+    Quantity value: (3, 5)
+    00000000 00000000 00000011 000000101
+                        aaq      aac
+
+    Args:
+        quantity (int): the initial quantity value
+
+    Returns:
+        The one byte armor/attack quantity as int and one byte armor/attack class as int
+    """
+    return quantity >> 8, quantity & 255
+
+def _aa_to_quantity(aa_quantity: int, aa_class: int) -> int:
+    """
+    A function to convert the quantity and armor/attack field to a quantity value.
+    Unfortunately this problem has to be solved in the object due to how specific this was implemented in DE.
+
+
+    Args:
+        aa_quantity (int): the armor quantity value
+        aa_class (int): the armor/attack value
+
+    Returns:
+        The one byte quantity and one byte armor/attack value
+    """
+    # Would use `aa_quantity << 8` - but apparently multiplication is faster
+    return aa_quantity * 256 + aa_class
