@@ -9,7 +9,7 @@ class Variable(AoE2Object):
 
     _link_list = [
         RetrieverObjectLink("variable_id", "Triggers", "variable_data[__index__].variable_id"),
-        RetrieverObjectLink("name", "Triggers", "variable_data[__index__].name"),
+        RetrieverObjectLink("name", "Triggers", "variable_data[__index__].variable_name"),
     ]
 
     def __init__(self, variable_id: int, name: str):
